Calculate the net reproduction number ($R_0$) from an age or stage-classified demographic projection matrix.
calc.ro(A, N.out = FALSE)A demographic projection matrix
Return the fundamental matrix (N) of the Markov chain.
If the (default) option N.out=FALSE is used, the net reproduction number is returned as a single value. If N.out = TRUE, the returned value is a list of two items:
Net reproduction number.
Fundamental matrix.
Calculates the net reproduction number ($R_0$) from an age or stage-classified demographic projection matrix by first decomposing the k x k projection matrix A into two component matrices, T and F. T collects the transitions between life-cycle stages while F collects the fertility transitions. For an age-classified Leslie matrix, T will contain only the sub-diagonal of A and F will contain only the first row of A. The fundamental matrix is given by $N = (I-T)^-1$, where I is a k x k identity matrix. $R_0$ is the leading eigenvalue of the matrix FN.
Caswell, H. (2001). Matrix population models: construction, analysis, and interpretation, Second edition. Sinauer, Sunderland, Massachusetts, USA.