Learn R Programming

strandCet (version 1.0)

cohort: Cohort method

Description

Dummy function called in life.Leslie

Usage

cohort(width12)

Arguments

width12

Width of the first two age classes.

Value

A two element vector representing the first two values of the nax column of the life table.

See Also

life.Leslie