Learn R Programming

strandCet (version 1.0)

expt.upts: Expected number of unique inputs after the final IMIS re-sample.

Description

Performance measure for the IMIS algorithm that calculates the expected number of unique points after re-sampling.

Usage

expt.upts(w, m)

Arguments

w

A vector of importance weights corresponding to each row of the mixture of the prior and multivariate gaussian distributions.

m

The final re-sample size.

Value

A scalar describing the number of unique points from the final re-sample.

References

Raftery, A. and Bao, L. (2009). Estimating and Projecting Trends in HIV/AIDS Generalized Epidemics Using Incremental Mixture Importance Sampling. Technical Report 560, Department of Statistics, University of Washington.

Sharrow, D.J., Clark, S.J., Collinson, M.A., Kahn, K. and Tollman, S.M. (2013). The Age Pattern of Increases in Mortality Affected by HIV: Bayesian Fit of the Heligman-Pollard Model to Data from the Agincourt HDSS Field Site in Rural Northeast South Africa. Demogr. Res. 29, 1039<U+2013>1096.

See Also

final.resamp