powered by
Dummy function called in life.Leslie
life.Leslie
cohort(width12)
Width of the first two age classes.
A two element vector representing the first two values of the nax column of the life table.