Performance measure for the IMIS algorithm that calculates the entropy of the importance weights relative to uniformity.
entropy.wts(w)A vector of importance weights corresponding to each row of the mixture of the prior and multivariate gaussian draws.
Vector of entropy values relative to uniformity for a vector of weights.
Raftery, A. and Bao, L. (2009). Estimating and Projecting Trends in HIV/AIDS Generalized Epidemics Using Incremental Mixture Importance Sampling. Technical Report 560, Department of Statistics, University of Washington.
Poole, D. and Raftery, A. (2000). Inference for Deterministic Simulation Models: The Bayesian Melding Approach. Journal of the American Statistical Association 95:1244<U+2013>1255.
Sharrow, D.J., Clark, S.J., Collinson, M.A., Kahn, K. and Tollman, S.M. (2013). The Age Pattern of Increases in Mortality Affected by HIV: Bayesian Fit of the Heligman-Pollard Model to Data from the Agincourt HDSS Field Site in Rural Northeast South Africa. Demogr. Res. 29, 1039<U+2013>1096.